library(ggplot2)
library(foreign)
library(ggpubr)

## Creates a violin+box plot
viobox <- function(p){
  p <- p + geom_violin(trim = FALSE, adjust = .5)
  p <- p + geom_boxplot(width = 0.1, size = 0.75)
  p <- p + geom_hline(aes(yintercept=0), linetype=2, size = 0.75, colour = "#333333")
  p <- p + theme_bw()
  p <- p + theme(legend.position="none")
  p <- p + theme(plot.title = element_text(lineheight=.8, face="bold", size = 22), 
                 axis.title = element_text(face = "bold", size = 18),
                 axis.text = element_text(colour = "black", size = 16),
                 panel.border = element_rect(colour='black', size=1.5),
                 strip.text = element_text(face = "bold", size = 20, color="white"),
                 strip.background = element_rect(fill="black"))
  p <- p + scale_fill_manual(values=c("#CC6666", "#9999CC", "#66CC99"))
  p
}

## Load the data and set up the model predictors 
data <- data.frame(read.spss("analysis2.sav"))
data$Condition <- factor(data$Condition, 
                         levels = c("P.R", "D.R", "control"),
                         labels = c("Pause", "Dialogic", "Control"))
data$SES <- factor(data$SES, labels = c("Low SES", "High SES"))
data$PNum <- factor(data$PNum)
mlu <- data.frame(read.spss("MLU analysis.sav"))
mlu$Condition <- factor(mlu$Condition, 
                        levels = c("P.R", "D.R", "control"),
                        labels = c("Pause", "Dialogic", "Control"))
mlu$SES <- factor(mlu$SES, labels = c("Low SES", "High SES"))
mlu$PNum <- factor(mlu$PNum)

## Create Plot grid
p <- ggplot(data, aes(x=Condition, y=GainExp))
p1 <- viobox(p) + facet_wrap(~SES) + ylab("Change in Expressive\nLanguage Score") + xlab("Intervention Group")
p <- ggplot(data, aes(x=Condition, y=GainRecp))
p2 <- viobox(p) + facet_wrap(~SES) + ylab("Change in Receptive\nLanguage Score") + xlab("Intervention Group")
p <- ggplot(data, aes(x=Condition, y=CelfGain))
p3 <- viobox(p) + facet_wrap(~SES) + ylab("Change in Syntax\nComprehension Score") + xlab("Intervention Group")
p <- ggplot(mlu, aes(x=Condition, y=ToyMLUGain))
p4 <- viobox(p) + facet_wrap(~SES) + ylab("Change in MLU\nScore") + xlab("Intervention Group")
ggsave("ReadingRCT_Violin-Plot.png", ggarrange(p1,p2,p3,p4, nrow=2, ncol=2),
       width=18, height=9, dpi = 300)
